#
# spec file for package proj
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define gridver 1.8
%define sover   19
%define libname lib%{name}%{sover}
Name:           proj
Version:        7.0.0
Release:        lp152.1.3
Summary:        Cartographic projection software
License:        MIT
Group:          Productivity/Scientific/Other
URL:            https://proj.org/
Source0:        http://download.osgeo.org/proj/%{name}-%{version}.tar.gz
Source1:        http://download.osgeo.org/proj/%{name}-datumgrid-%{gridver}.zip
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig >= 0.9.0
BuildRequires:  sqlite3
BuildRequires:  unzip
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(sqlite3) >= 3.11
Provides:       libproj = %{version}
%if 0%{?suse_version} > 1500
BuildRequires:  pkgconfig(gtest)
%endif

%description
This package offers the commandline tools for performing respective
forward and inverse transformation of cartographic data to or from cartesian
data with a wide range of selectable projection functions.

%package -n %{libname}
Summary:        Cartographic projection software
Group:          Development/Libraries/C and C++

%description -n %{libname}
This package the library for performing respective
forward and inverse transformation of cartographic data to or from cartesian
data with a wide range of selectable projection functions.

%package devel
Summary:        Development files for PROJ
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Provides:       libproj-devel = %{version}
Obsoletes:      libproj-devel < %{version}

%description devel
This package contains libproj and the appropriate header files and man pages.

%prep
%setup -q
cd data
unzip -o %{SOURCE1}

%build
%configure \
%if 0%{?suse_version} > 1500
  --with-external-gtest \
%endif
  --disable-static \
  --enable-lto
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%check
# Tests dont work on i586 and noone cares
%ifnarch %{ix86}
%make_build check
%endif

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files
%doc NEWS AUTHORS README ChangeLog
%defattr(0755,root,root)
%{_bindir}/cs2cs
%{_bindir}/cct
%{_bindir}/gie
%{_bindir}/geod
%{_bindir}/invgeod
%{_bindir}/invproj
%{_bindir}/proj
%{_bindir}/projsync
%{_bindir}/projinfo
%defattr(0644,root,root)
%{_mandir}/man1/cs2cs.1%{?ext_man}
%{_mandir}/man1/geod.1%{?ext_man}
%{_mandir}/man1/proj.1%{?ext_man}
%{_mandir}/man1/cct.1%{?ext_man}
%{_mandir}/man1/gie.1%{?ext_man}
%{_mandir}/man1/projinfo.1%{?ext_man}
%{_mandir}/man1/projsync.1%{?ext_man}
%{_datadir}/proj/

%files -n %{libname}
%license COPYING
%{_libdir}/libproj.so.%{sover}*

%files devel
%{_includedir}/*.h
%{_includedir}/proj
%{_libdir}/libproj.so
%{_libdir}/pkgconfig/proj.pc

%changelog
* Tue Mar 31 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 7.0.0:
  * Added new file access API to proj.h #866
  * Updated the name of the most recent version of the WKT2 standard from
    WKT2_2018 to WKT2_2019 to reflect the proper name of the standard (#1585)
  * Improvements in transformations from/to WGS 84 (Gxxxx) realizations and
    vertical <--> geog transormations #1608
  * Update to version 1.50 of the geodesic library (#1629)
  * Promote proj_assign_context to proj.h from proj_experimental.h (#1630)
  * Add rotation support to the HEALPix projection (#1638)
  * Add c function proj_crs_create_bound_vertical_crs() (#1689)
  * Use Win32 Unicode APIs and expect all strings to be UTF-8 (#1765)
  * Improved name aliases lookup (#1827)
  * CMake: Employ better use of CTest with the BUILD_TESTING option (#1870)
  * Grid correction: fix handling grids spanning antimeridian (#1882)
  * Remove legacy CMake target name "proj" #1883
  * projinfo: add --searchpaths switch (#1892)
  * Add +proj=set operation to set component(s) of a coordinate to a fixed
    value (#1896)
  * Add EPSG records for 'Geocentric translation by Grid Interpolation (IGN)'
    (gr3df97a.txt) and map them to new +proj=xyzgridshift (#1897)
  * Remove 'null' grid file as it is now a special hardcoded case in grid
    code (#1898)
  * Add projsync utility (#1903)
  * Make PROJ the CMake project name #1910
  * Use relative directory to locate PROJ resource files (#1921)
* Mon Mar  9 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 6.3.1:
  * Updates
  - Update the EPSG database to version 9.8.6
  - Database: add mapping for gg10_smv2.mnt and gg10_sbv2.mnt French grids
  - Database: add mapping for TOR27CSv1.GSB
  * Bug fixes
  - Fix wrong use of derivingConversionRef() that caused issues with use of
    +init=epsg:XXXX by GDAL (affecting R spatial libraries) or in MapServer
  - fix exporting CoordinateSystem to PROJ JSON with ID
  - projinfo: use No. abbreviation instead of UTF-8 character (#1828)
  - CompoundCRS::identify(): avoid exception when horiz/vertical part is a
    BoundCRS
  - createOperations(): fix dealing with projected 3D CRS whose Z units != metre
  - WKT1_GDAL export: limit datum name massaging to names matching EPSG (#1835)
  - unitconvert with mjd time format: avoid potential integer overflow
    (ossfuzz 20072)
  - ProjectedCRS::identify(): fix wrong identification of some ESRI WKT linked
    to units
  - Database: add a geoid_like value for proj_method column of grid_alternatives,
    fix related entries and simplify/robustify logic to deal with EPSG
    'Geographic3D to GravityRelatedHeight' methods
  - Fix ingestion of +proj=cea with +k_0 (#1881)
  - Fix performance issue, affecting PROJ.4 string generation of EPSG:7842
    (#1913)
  - Fix identification of ESRI-style datum names starting with D_ but without
    alias (#1911)
  - cart: Avoid discontinuity at poles in the inverse case (#1906)
  - Various updates to make regression test suite pass with gcc on i386 (#1906)
- Changleog from 6.3.0:
  * Updates
  - Database: tune accuracy of Canadian NTv1 file w.r.t NTv2 (#1812)
  - Modify verbosity level of some debug/trace messages (#1811)
  - projinfo: no longer call createBoundCRSToWGS84IfPossible() for WKT1:GDAL
    (#1810)
  - proj_trans: add retry logic to select other transformation if the best one
    fails. (#1809)
  - BoundCRS::identify(): improvements to discard CRS that aren't relevant
    (#1802)
  - Database: update to IGNF v3.1.0 (#1785)
  - Build: Only export symbols if building DLL (#1773)
  - Database: update ESRI entries with ArcGIS Desktop version 10.8.0 database
    (#1762)
  - createOperations(): chain operations whose middle CRSs are not identical but
    have the same datum (#1734)
  - import/export PROJJSON: support a interpolation_crs key to geoid_model
    (#1732)
  - Database: update to EPSG v9.8.4 (#1725)
  - Build: require SQLite 3.11 (#1721)
  - Add support for GEOIDMODEL (#1710)
  - Better filtering based on extent and performance improvements (#1709)
  * Bug fixes
  - Horizontal grid shift: fix issue on iterative inverse computation when
    switching between (sub)grids (#1797)
  - createOperations(): make filtering out of 'uninteresting' operations less
    aggressive (#1788)
  - Make EPSG:102100 resolve to ESRI:102100 (#1786)
  - ob_tran: restore traditional handling of +to_meter with pj_transform() and
    proj utility (#1783)
  - CRS identification: use case insensitive comparison for authority name
    (#1780)
  - normalizeForVisualization() and other methods applying on a ProjectedCRS: do
    not mess the derivingConversion object of the original object (#1746)
  - createOperations(): fix transformation computation from/to a CRS with
    +geoidgrids and +vunits != m (#1731)
  - Fix proj_assign_context()/pj_set_ctx() with pipelines and alternative coord
    operations (#1726)
  - Database: add an auxiliary concatenated_operation_step table to allow
    arbitrary number of steps (#1696)
  - Fix errors running gie-based tests in Debug mode on Windows (#1688)
* Tue Nov  5 2019 Angelos Tzotsos <tzotsos@opensuse.org>
- Update to version 6.2.1:
  * Update the EPSG database to version 9.8.2
  * Fixed erroneous spelling of "Potsdam" (#1573)
  * Calculate y-coordinate correctly in bertin1953 in all cases (#1579)
  * proj_create_crs_to_crs_from_pj(): make the PJ* arguments const PJ* (#1583)
  * PROJStringParser::createFromPROJString(): avoid potential infinite recursion (#1574)
  * Avoid core dump when setting ctx==NULL in functions proj_coordoperation_is_instantiable and
  * proj_coordoperation_has_ballpark_transformation (#1590)
  * createOperations(): fix conversion from/to PROJ.4 CRS strings with non-ISO-kosher options and +towgs84/+nadgrids (#1602)
  * proj_trans_generic(): properly set coordinate time to HUGE_VAL when no value is passed to the function (#1604)
  * Fix support for +proj=ob_tran +o_proj=lonlat/latlong/latlon instead of only only allowing +o_proj=longlat (#1601)
  * Improve backwards compatibility of vertical transforms (#1613)
  * Improve emulation of deprecated +init style initialization (#1614)
  * cs2cs: autopromote CRS to 3D when there's a mix of 2D and 3D (#1563)
  * Avoid divisions by zero in odd situations (#1620)
  * Avoid compile error on Solaris (#1639)
  * proj_create_crs_to_crs(): fix when there are only transformations with ballpark steps (#1643)
  * PROJ string CRS ingester: recognize more unit-less parameters, and handling of +key=string_value parameters (#1645)
  * Only call pkg-config in configure when necessary (#1652)
  * aeqd: for spherical forward path, go to higher precision ellipsoidal case when the point coordinates are super close to the origin (#1654)
  * proj_create_crs_to_crs(): remove elimination of Ballpark operations that caused transformation failures in some cases (#1665)
  * createOperations(): allow transforming from a compoundCRS of a bound verticalCRS to a 2D CRS (#1667)
  * Avoid segfaults in case of out-of-memory situations (#1679)
  * createOperations(): fix double vertical unit conversion from CompoundCRS to other CRS when the horizontal part of the projected CRS uses non-metre unit (#1683)
  * importFromWkt(): fix axis orientation for non-standard ESRI WKT (#1690)
* Tue Oct 29 2019 Angelos Tzotsos <tzotsos@opensuse.org>
- Fix Leap build target
* Fri Sep 27 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 6.2.0:
  * Introduced PROJJSON, a JSON encoding of WKT2 (#1547)
  * Support CRS instantiation of OGC URN's (#1505)
  * Expose scope and remarks of database objects (#1537)
  * EPSG Database updated to version 9.7.0 (#1558)
  * Added C API function proj_grid_get_info_from_database() (#1494)
  * Added C API function
    proj_operation_factory_context_set_discard_superseded() (#1534)
  * Added C API function proj_context_set_autoclose_database() (#1566)
  * Added C API function proj_create_crs_to_crs_from_pj() (#1567)
  * Added C API function proj_cleanup() (#1569)
  * Fixed build failure on Solaris systems (#1554)
* Wed Jun 12 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 6.1.0:
  * See provided NEWS for list of all changes
* Mon Apr  1 2019 Kai Pastor <dg0yt@darc.de>
- Fix datumgrid packaging
* Mon Mar 25 2019 Martin Pluskal <mpluskal@suse.com>
- Enable tests
- Fix previous changelog entry
* Mon Mar 11 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 6.0.0 and datumgrid 1.7
  * See provided NEWS for list of all changes
* Wed Sep 19 2018 Martin Pluskal <mpluskal@suse.com>
- Update to version 5.2.0 and datumgrid 1.7
  * See provided NEWS for list of all changes
* Thu Jul 12 2018 mpluskal@suse.com
- Update to version 5.1.0 and datumgrid 1.7
  * See provided NEWS for list of all changes
* Sun Oct  2 2016 tzotsos@opensuse.org
- Update to 4.9.3
  o update to new datumgrid version 1.6
* Fri Sep 30 2016 tzotsos@opensuse.org
- Switch download link to OSGeo server
* Mon Jul  4 2016 mpluskal@suse.com
- Update project and download url
- Small spec file cleanups
* Sun Sep 27 2015 mpluskal@suse.com
- Update to 4.9.2
  o proj_def.dat was missing from source distribution
    see https://github.com/OSGeo/proj.4/issues/274 for more detail
  o Update Geodesic library from GeographicLib
  o Remove setlocale() use in pj_init_ctx()
  o Renamed PVALUE in pj_param.c to prevent clash with Windows
* Sat May  9 2015 mpluskal@suse.com
- Update to 4.9.1
  o 4.9.0RC2 release was abandoned because it was not promoted in a
    timely fashion. Subsequent maintenance of tickets has continued,
    and a new 4.9.1 release was issued in its place.
  o Implement inverse solution for Winkel Tripel from Drazan Tutic #250
  o More CMake configuration tweaks. The CMake configuration is probably
    not at feature parity with the autotools builds at this point but it
    is converging #256
  o Tweak initialization ordering around setlocal which may have caused
    issues #237
  o Support out-of-tree autoconf builds more completely #247
  o Fix NaN handling by geod_inverse and geod_polygon_addedge #251 & #253
  o Update config.sub and config.guess #257
  o Adapt Charles Karney's CMake patches for smoother build #258
  o Define default PROJ_LIB location for CMake compilation #261
  o Fix Windows compilation on PJ_aitoff.c
  o Align CMake SOVERSION with autotools #263
  o Regenerate nad/epsg with GDAL r28536 to avoid precision loss in TOWGS84
    parameters, e.g. on Amersfoort / RD EPSG:4289 (#260)
  o Add CMake project-config.cmake scripts (#264 from Charles Karney)
  o Dial back test sensitivity #255
- Changes for 4.9.0
  o Implement CMake as an option for building PROJ.4
  o Implement new virtual file api (projFileAPI) so that all access to grid
    shift and init files can be hooked.
  o Replace geodesic implementation with one from Charles Karney and add a
    supported public interface (geodesic.h).
  o Upgraded to EPSG 8.5.
  o Removed old (deprecated) Java bindings in favor of the new api introduced
    in 4.8.0.
  o Implement the calcofi (Cal Coop Ocean Fish Invest Lines/Stations) projection
  o Install projects.h again for applications that want access to internal
    structures and functions despite the inherent fragility.
  o Various bug fixes and cleanup.
  o Added the CalCOFI pseudo-projection, #135
* Sun Mar  8 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Cleanup dependecies
- Use url for source
- Update url
* Fri Apr 20 2012 tzotsos@opensuse.org
- minor fix to install projects.h needed in devel package.
* Wed Mar 14 2012 dassau@gbd-consult.de
- update to version 4.8.0
  - Added the Natural Earth projection.
  - Added HEALPIX, rHEALPIX and Icosahedral Snyder Equal Area projections.
  - nad2bin now produces "CTable2" format grid shift files by default which
  are platform independent.
  - nad2nad removed, use cs2cs for datum shift operations.
  - projects.h no longer installed as a public include file.  Please try to
  only use proj_api.h.
  - Add pj_get_spheroid_defn() accessor.
  - Added an alternate version of pj_init() that takes a projCtx (execution
  context) structure to address multithreading issues with error management
  and to provide a support for application hookable error reporting and
  logging.
  - Upgrade to EPSG 7.9.  Some changes in ideal datum selection.
  - JNI bindings reworked, org.proj4.Projections deprecated in favor of
  org.proj4.PJ.
  - Added preliminary vertical datum support.
  - Fix various multithreading issues, particular in datum grid handling code.
  - Added support for the +axis= option for alternate axis orientations as
  part of a coordinate system (used for TM South Orientated support).
  - +proj=omerc implementatioin replaced with code from libproj4.  +rot_conv
  flag no longer works, and some coordinate systems (ie. Malaysian) will
  need to use +gamma instead.  "epsg" init file updated accordingly.
- Added BuildRequires pkg-config
- Added %%{_libdir}/pkgconfig/proj.pc
* Thu Aug 18 2011 idonmez@novell.com
- Remove wrong -static-devel package
* Thu Aug 18 2011 otto.dassau@gmx.de
- added a static devel package, because GRASS and QGIS don't find
  the external PROJ.4 data directory anymore
  Sat Mar 19 00:00:00 UTC 2011 - Otto Dassau 4.7.0
- removed debug_package
  Tue Nov 24 00:00:00 UTC 2009 - Otto Dassau 4.7.0
- update to new proj4 version
- update to new datumgrid version 1.5
* Sun Oct 19 2008 dl9pf@gmx.de
- change spec to build on factory
  Wed Sep 17 00:00:00 UTC 2008 - Otto Dassau 4.6.1
- version update
  Wed Jul  9 00:00:00 UTC 2008 - Otto Dassau 4.6.0
- update and rpmlind fixes
  Mon Aug 13 00:00:00 UTC 2007 - Dirk Stöcker 4.5.0
- adapted to BuildService
  Fri Jan  5 00:00:00 UTC 2007 - Otto Dassau 4.5.0
- moved *.so from files devel to files
  Tue Dec 19 00:00:00 UTC 2006 - Otto Dassau 4.5.0
- rebuilt for SuSE 10.2
  Wed Jan 25 00:00:00 UTC 2006 - Otto Dassau 4.4.9
- rebuilt for SuSE 10.0 and added devel package
  Thu Nov 17 00:00:00 UTC 2005 - Markus Neteler 4.4.9
- upgraded to Mandriva 2006
  Fri Aug  5 00:00:00 UTC 2005 - Otto Dassau 4.4.9
- Applied for Mandrake 10.1 RPM
